@@ -61,9 +61,9 @@ proc Url_Dispatch {sock} {
     if {(![info exists data(query)] || [string length $data(query)] == 0) \
 	    && [info exists UrlCache($url)]} {
 	Count cachehit,$url
-	if [catch {
+	if {[catch {
 	    eval $UrlCache($url) {$sock}
-	}] {
+	}]} {
 	    catch {Url_UnCache $sock}
 	} else {
 	    return
@@ -109,7 +109,7 @@ proc Url_Dispatch {sock} {
 		# these are all plugged up.
 		Count numfiles
 		Httpd_SockClose $sock 1 $error
-		File_Reset $sock $error
+		File_Reset
 	    } 
 	    default {
 		Doc_Error $sock $errorInfo
@@ -182,9 +182,12 @@ proc Url_PathCheck {urlsuffix} {
     global Url
     set pathlist ""
     foreach part  [split $urlsuffix /] {
+	if {[string length $part] == 0} {
+	    continue
+	}
 	set part [Url_Decode $part]
 	# Disallow Mac and UNIX path separators in components
-	if [regexp $Url(fsSep) $part] {
+	if {[regexp $Url(fsSep) $part]} {
 	    error "URL components cannot include $Url(fsSep)"
 	}
 	switch -- $part {
@@ -207,8 +210,11 @@ proc Url_PathCheck {urlsuffix} {
 # convert a x-www-urlencoded string into a list of name/value pairs
 
 proc Url_DecodeQuery {query args} {
-    array set options {-type application/x-ww-urlencoded -qualifiers {}}
+    array set options {-type application/x-www-urlencoded -qualifiers {}}
     catch {array set options $args}
+    if {[string length [info command Url_DecodeQuery_$options(-type)]] == 0} {
+	set options(-type) application/x-www-urlencoded
+    }
     return [Url_DecodeQuery_$options(-type) $query $options(-qualifiers)]
 }
 
@@ -232,8 +238,13 @@ proc UrlDecodeData {data} {
     return [subst $data]
 }
 
-proc Url_DecodeQuery_application/x-www-form-urlencoded {query qualifiers} [info body Url_DecodeQuery_application/x-www-urlencoded]
-proc Url_DecodeQuery_application/x-ww-urlencoded {query qualifiers} [info body Url_DecodeQuery_application/x-www-urlencoded]
+# Sharing procedure bodies doesn't work with compiled procs,
+# so these call each other instead of doing
+# proc xprime [info args x] [info body x]
+
+proc Url_DecodeQuery_application/x-www-form-urlencoded {query qualifiers} {
+    Url_DecodeQuery_application/x-www-urlencoded $query $qualifiers
+}
 
 # steve: 5/8/98: This is a very crude start at parsing MIME documents
 # Return filename/content pairs
